@@ -258,8 +258,8 @@ def get_cluster_id(in_df, in_df_tambon_cluster):
     dict_tambon_cluster = tmp_df_tambon_cluster.set_index('tambon_pcode')['full_cluster_id'].squeeze().to_dict()
     
     #get default cluster for each province
-    df_prov_default_cluster = tmp_df_tambon_cluster.groupby(['plant_province_code','full_cluster_id'], as_index=False).agg(count=pd.namedagg(column='tambon_pcode', aggfunc='size'))
-    df_prov_default_cluster = df_prov_default_cluster.sort_values('count', ascending=False).drop_duplicates(['plant_province_code'])
+    df_prov_default_cluster = tmp_df_tambon_cluster.assign(count=1).groupby(['plant_province_code','full_cluster_id'], as_index=False).agg(count=('count', 'count'))
+    df_prov_default_cluster = df_prov_default_cluster.sort_values('count', ascending=False).drop_duplicates(subset=['plant_province_code'])
     dict_prov_default_cluster =  df_prov_default_cluster.set_index('plant_province_code')['full_cluster_id'].squeeze().to_dict()
     
     arr_default_cluster = dict_tools.map_dict(out_df['plant_province_code'].values, dict_prov_default_cluster)
@@ -267,6 +267,7 @@ def get_cluster_id(in_df, in_df_tambon_cluster):
  
     return out_df
 
+
     
 
 def get_breed_info(in_df, in_df_breed_info, in_region_cd):
